@@ -45,7 +45,7 @@ multi_transmat <- function (pre_test = NULL, pst_test = NULL,
   res <- list()
 
   # Get transition matrix for each item pair
-  for (i in 1:n_items) {
+  for (i in seq_len(n_items)) {
 
     # cat("\n Item", i, "\n")
     res[[i]] <- transmat(pre_test[, i], pst_test[, i], force9 = force9)
